import { useEffect, useState } from 'react'
import InputWithDropDown from '../../../../../ui/inputs/InputWithDropDown'
import RenameInput from '../../../../../ui/inputs/RenameInput'
import LabledDropdown from '../../../../../ui/inputs/LabledDropdown'
import Trigger from '../trigger/Trigger'
import { useSelectedEventData, useSelectedProduct } from "../../../../../../store/simulation/useSimulationStore";
import { useProductStore } from "../../../../../../store/simulation/useProductStore";
import TravelAction from '../actions/TravelAction'

function VehicleMechanics() {
    const [activeOption, setActiveOption] = useState("default");
    const [selectedPointData, setSelectedPointData] = useState<PointsScheme | undefined>();
    const { selectedEventData } = useSelectedEventData();
    const { getPointByUuid } = useProductStore();
    const { selectedProduct } = useSelectedProduct();

    useEffect(() => {
        if (selectedEventData) {
            const point = getPointByUuid(selectedProduct.productId, selectedEventData?.data.modelUuid, selectedEventData?.selectedPoint);
            if (point && 'action' in point) {
                setSelectedPointData(point as PointsScheme & { action: { actionType: string } });
                setActiveOption((point as PointsScheme & { action: { actionType: string } }).action.actionType);
            }
        }
    }, [selectedProduct, selectedEventData])

    const availableActions = {
        defaultOption: "travel",
        options: ["travel"],
    };

    return (
        <>
            {selectedEventData &&
                <>
                    <div className="global-props">
                        <div className="property-list-container">
                            <div className="property-item">
                                <InputWithDropDown
                                    label="Speed"
                                    value="0.5"
                                    min={0}
                                    step={0.1}
                                    defaultValue={"0.5"}
                                    max={10}
                                    activeOption="s"
                                    onClick={() => { }}
                                    onChange={(value) => console.log(value)}
                                />
                            </div>
                        </div>
                    </div>

                    <div className="selected-actions-details">
                        <div className="selected-actions-header">
                            <RenameInput value="Action Name" />
                        </div>
                        <div className="selected-actions-list">
                            <LabledDropdown
                                defaultOption={selectedPointData && 'action' in selectedPointData
                                    ? (selectedPointData as PointsScheme & { action: { actionType: string } }).action.actionType
                                    : "default"}
                                options={availableActions.options}
                                onSelect={(option) => setActiveOption(option)}
                            />
                            {activeOption === "travel" && <TravelAction />}
                        </div>
                    </div>
                    <div className="tirgger">
                        <Trigger />
                    </div>
                </>
            }
        </>
    )
}

export default VehicleMechanics